Name:          libdirac
Version:       1.0.2
Release:       4mamba
Summary:       Libraries for Dirac
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           http://diracvideo.org/
Source:        http://diracvideo.org/download/dirac-research/dirac-%{version}.tar.gz
License:       LGPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libcppunit-devel
BuildRequires: libgcc
BuildRequires: libstdc++6-devel
BuildRequires: perl-devel
## AUTOBUILDREQ-END
BuildRequires: libcppunit-devel >= 1.15.1-1mamba
BuildRequires: doxygen
BuildRequires: libgraphviz-devel
BuildRequires: tetex-latex
BuildRequires: tetex
BuildRoot:     %{_tmppath}/%{name}-%{version}-root

%description
Dirac is an open source video codec. It uses a traditional hybrid video codec architecture, but with the wavelet transform instead of the usual block transforms.  Motion compensation uses overlapped blocks to reduce block artefacts that would upset the transform coding stage.

This package contains libraries for Dirac

%package devel
Group:         Development/Libraries
Summary:       Libraries and headers for Dirac
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description devel
Dirac is an open source video codec. It uses a traditional hybrid video codec architecture, but with the wavelet transform instead of the usual block transforms.  Motion compensation uses overlapped blocks to reduce block artefacts that would upset the transform coding stage.

This package contains libraries and header files need for development.

%package static
Group:         Development/Libraries
Summary:       Static libraries for Dirac
Requires:      %{name}-devel = %{?epoch:%epoch:}%{version}-%{release}

%description static
Dirac is an open source video codec. It uses a traditional hybrid video codec architecture, but with the wavelet transform instead of the usual block transforms.  Motion compensation uses overlapped blocks to reduce block artefacts that would upset the transform coding stage.

This package contains static libraries need for development.

%package -n Dirac-docs
Group:         Documentation
Summary:       Documentation for Dirac
Requires:      Dirac = %{?epoch:%epoch:}%{version}-%{release}

%description -n Dirac-docs
Dirac is an open source video codec. It uses a traditional hybrid video codec architecture, but with the wavelet transform instead of the usual block transforms.  Motion compensation uses overlapped blocks to reduce block artefacts that would upset the transform coding stage.

This package contains documentation files for Dirac.

%package -n Dirac
Group:         System/Libraries
Summary:       Dirac is an open source video codec 

%description -n Dirac
Dirac is an open source video codec. It uses a traditional hybrid video codec architecture, but with the wavelet transform instead of the usual block transforms.  Motion compensation uses overlapped blocks to reduce block artefacts that would upset the transform coding stage.

%prep

%setup -q -n dirac-%{version}

install -pm 644 README README.Dirac
install -pm 644 util/instrumentation/README README.instrumentation
# fix permission mode for sources.
find doc unit_tests util libdirac_encoder libdirac_byteio -type f -name \* -exec chmod 644 {} \;


# Only update the doxygen file before generated with make
pushd doc/
%{_bindir}/doxygen -u dirac_api.doxygen
popd

%build
%configure\
  --program-prefix=dirac_ \
  --program-transform-name=s,dirac_dirac_,dirac_, \
  --enable-overlay \
  --enable-mmx=no \

sed -i -e 's|-Werror||' decoder/Makefile

# remove rpath from libtool (may be unneeded)
sed -i.rpath 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i.rpath 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall
# Transform-name fix
mv %{buildroot}%{_bindir}/dirac_create_dirac_testfile.pl \
	%{buildroot}%{_bindir}/create_dirac_testfile.pl
sed -i -e 's|"RGBtoYUV"|"dirac_RGBtoYUV"|g' %{buildroot}%{_bindir}/create_dirac_testfile.pl
sed -i -e 's|/home/guest/dirac-0.5.0/util/conversion|%{_bindir}|' %{buildroot}%{_bindir}/create_dirac_testfile.pl


%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_libdir}/*.so.*
%doc AUTHORS COPYING ChangeLog NEWS README TODO

%files devel
%defattr(-,root,root)
%dir %{_includedir}/dirac/libdirac_common
%{_includedir}/dirac/libdirac_common/*.h
%dir %{_includedir}/dirac/libdirac_decoder
%{_includedir}/dirac/libdirac_decoder/*.h
%dir %{_includedir}/dirac/libdirac_encoder
%{_includedir}/dirac/libdirac_encoder/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files static
%defattr(-,root,root)
%{_libdir}/*.a
%{_libdir}/*.la

%files -n Dirac-docs
%defattr(-,root,root)
%dir %{_docdir}/dirac/code/api_html
%{_docdir}/dirac/code/api_html/*

%files -n Dirac
%defattr(-,root,root)
%{_bindir}/create_dirac_testfile.pl
%{_bindir}/dirac_BMPtoRGB
%{_bindir}/dirac_RGBtoBMP
%{_bindir}/dirac_RGBtoUYVY
%{_bindir}/dirac_RGBtoYUV411
%{_bindir}/dirac_RGBtoYUV420
%{_bindir}/dirac_RGBtoYUV422
%{_bindir}/dirac_RGBtoYUV444
%{_bindir}/dirac_UYVYtoRGB
%{_bindir}/dirac_UYVYtoYUV422
%{_bindir}/dirac_YUV411toRGB
%{_bindir}/dirac_YUV420Down2x2
%{_bindir}/dirac_YUV420ItoYUV422I
%{_bindir}/dirac_YUV422ItoYUV420I
%{_bindir}/dirac_YUV420pt75filter
%{_bindir}/dirac_YUV420toRGB
%{_bindir}/dirac_YUV420toYUV422
%{_bindir}/dirac_YUV422toRGB
%{_bindir}/dirac_YUV422toUYVY
%{_bindir}/dirac_YUV422toYUV420
%{_bindir}/dirac_YUV444toRGB
%{_bindir}/dirac_decoder
%{_bindir}/dirac_encoder
%{_bindir}/dirac_instrumentation
%{_bindir}/dirac_unittest

%changelog
* Sun May 03 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.2-4mamba
- rebuilt by autoport with build requirements: libcppunit-devel>=1.15.1-1mamba

* Tue Aug 21 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.2-3mamba
- rebuilt by autoport with build requirements: libcppunit-devel>=1.14.0-1mamba

* Tue Dec 04 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.2-2mamba
- rebuilt with libcppunit 1.13.1

* Mon Mar 02 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.2-1mamba
- automatic update by autodist

* Fri Nov 21 2008 gil <puntogil@libero.it> 1.0.0-1mamba
- package created by autospec
